.. _io.fhiaims:

.. module:: sisl.io.fhiaims

FHIaims
=======

.. autosummary::
   :toctree: generated/

   inSileFHIaims


.. autosummary::
   :toctree: generated/
   :hidden:

   SileFHIaims
   SileBinFHIaims

